"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AzurePipelinesTasksDatasource = void 0;
const tslib_1 = require("tslib");
const decorator_1 = require("../../../util/cache/package/decorator");
const loose_1 = require("../../versioning/loose");
const datasource_1 = require("../datasource");
const TASKS_URL_BASE = 'https://raw.githubusercontent.com/renovatebot/azure-devops-marketplace/main';
const BUILT_IN_TASKS_URL = `${TASKS_URL_BASE}/azure-pipelines-builtin-tasks.json`;
const MARKETPLACE_TASKS_URL = `${TASKS_URL_BASE}/azure-pipelines-marketplace-tasks.json`;
class AzurePipelinesTasksDatasource extends datasource_1.Datasource {
    static id = 'azure-pipelines-tasks';
    constructor() {
        super(AzurePipelinesTasksDatasource.id);
    }
    customRegistrySupport = false;
    defaultVersioning = loose_1.id;
    async getReleases({ packageName, }) {
        const versions = (await this.getTasks(BUILT_IN_TASKS_URL))[packageName.toLowerCase()] ??
            (await this.getTasks(MARKETPLACE_TASKS_URL))[packageName.toLowerCase()];
        if (versions) {
            const releases = versions.map((version) => ({ version }));
            return { releases };
        }
        return null;
    }
    async getTasks(url) {
        const { body } = await this.http.getJson(url);
        return body;
    }
}
exports.AzurePipelinesTasksDatasource = AzurePipelinesTasksDatasource;
tslib_1.__decorate([
    (0, decorator_1.cache)({
        namespace: `datasource-${AzurePipelinesTasksDatasource.id}`,
        key: (url) => url,
        ttlMinutes: 24 * 60,
    })
], AzurePipelinesTasksDatasource.prototype, "getTasks", null);
//# sourceMappingURL=index.js.map