"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toMs = void 0;
const tslib_1 = require("tslib");
const is_1 = tslib_1.__importDefault(require("@sindresorhus/is"));
const ms_1 = tslib_1.__importDefault(require("ms"));
const logger_1 = require("../logger");
const regex_1 = require("./regex");
const splitRegex = (0, regex_1.regEx)(/(.*?[a-z]+)/);
function split(time) {
    return time
        .split(splitRegex)
        .map((x) => x.trim())
        .filter(is_1.default.nonEmptyString);
}
function applyCustomFormat(spec) {
    const monthRegex = (0, regex_1.regEx)(/^(\d+)\s*(?:months?|M)$/);
    return spec.replace(monthRegex, (_, months) => `${months * 30} days`);
}
function toMs(time) {
    try {
        const specs = split(time).map(applyCustomFormat);
        if (!specs.length) {
            logger_1.logger.debug({ time }, `Invalid time specifier: '${time}'`);
            return null;
        }
        let totalMillis = 0;
        for (const spec of specs) {
            const millis = (0, ms_1.default)(spec);
            if (!is_1.default.number(millis)) {
                logger_1.logger.debug({ time }, `Invalid time specifier: '${spec}'`);
                return null;
            }
            totalMillis += millis;
        }
        return totalMillis;
    }
    catch (err) {
        logger_1.logger.debug({ time, err }, `Invalid time specifier: '${time}'`);
        return null;
    }
}
exports.toMs = toMs;
//# sourceMappingURL=pretty-time.js.map